# Anybody here play Pokémon?
Just me? That's fine.

## The game:

[github.com/4ntoined/pokemonpy](https://github.com/4ntoined/pokemonpy)

## To play the game:

```
myterminal$ python3
python$ import adadpython.pokemon as pk
python$ game = pk.pokemonpygame()
python$ game.startgame()
```
#### To play with a particular config file:

```
myterminal$ python3
python$ import adadpython.pokemon as pk
python$ cpath = '/configurations/config.txt'
python$ game = pk.pokemonpygame()
python$ game.startgame(cpath)
```



